invenio-sword
#############

.. image:: https://travis-ci.org/swordapp/invenio-sword.svg?branch=master
   :target: https://travis-ci.org/swordapp/invenio-sword

.. image:: https://codecov.io/gh/swordapp/invenio-sword/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/swordapp/invenio-sword

.. image:: https://readthedocs.org/projects/invenio-sword/badge/?version=latest
   :target: https://invenio-sword.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

A prototypical implementation of the `SWORDv3
<https://swordapp.github.io/swordv3/swordv3.html>`_ deposit service within the
`Invenio <https://invenio-software.org/>`_ digital library framework.

